package br.jus.cnj.intercomunicacao.util;

import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.regex.Pattern;

public class ConversorData {
	
	private static String regexDataHora = "\\d{14}";
	
	private static String regexData = "\\d{8}";

	public static String converteParaDataInteroperabilidade(Date date) {
		StringBuilder sb = new StringBuilder();
		GregorianCalendar gc = new GregorianCalendar();
		gc.setTime(date);
		sb.append(String.format("%04d", gc.get(Calendar.YEAR)));
		sb.append(String.format("%02d", gc.get(Calendar.MONTH) + 1));
		sb.append(String.format("%02d", gc.get(Calendar.DAY_OF_MONTH)));
		return sb.toString();
	}

	public static String converteParaDataHoraInteroperabilidade(Date date) {
		StringBuilder sb = new StringBuilder();
		GregorianCalendar gc = new GregorianCalendar();
		gc.setTime(date);
		sb.append(String.format("%04d", gc.get(Calendar.YEAR)));
		sb.append(String.format("%02d", gc.get(Calendar.MONTH) + 1));
		sb.append(String.format("%02d", gc.get(Calendar.DAY_OF_MONTH)));
		sb.append(String.format("%02d", gc.get(Calendar.HOUR_OF_DAY)));
		sb.append(String.format("%02d", gc.get(Calendar.MINUTE)));
		sb.append(String.format("%02d", gc.get(Calendar.SECOND)));
		return sb.toString();
	}
	
	public static Date converteDeDataHoraInteroperabilidade(String data){
		// Entrada no formato AAAAMMDDHHMMSS
		if(!data.matches(regexDataHora)){
			throw new IllegalArgumentException("A data indicada [" + data + "] não obedece ao padrão esperado [AAAAMMDDHHMMSS].");
		}
		GregorianCalendar gc = new GregorianCalendar();
		gc.set(Calendar.YEAR, Integer.parseInt(data.substring(0, 4)));
		gc.set(Calendar.MONTH, Integer.parseInt(data.substring(4, 6)) - 1);
		gc.set(Calendar.DAY_OF_MONTH, Integer.parseInt(data.substring(6, 8)));
		gc.set(Calendar.HOUR_OF_DAY, Integer.parseInt(data.substring(8, 10)));
		gc.set(Calendar.MINUTE, Integer.parseInt(data.substring(10, 12)));
		gc.set(Calendar.SECOND, Integer.parseInt(data.substring(12, 14)));
		gc.set(Calendar.MILLISECOND, 0);
		return gc.getTime();
	}

	public static Date converteDeDataInteroperabilidade(String data){
		// Entrada no formato AAAAMMDD
		if(!data.matches(regexData)){
			throw new IllegalArgumentException("A data indicada [" + data + "] não obedece ao padrão esperado [AAAAMMDD].");
		}
		GregorianCalendar gc = new GregorianCalendar();
		gc.set(Calendar.YEAR, Integer.parseInt(data.substring(0, 4)));
		gc.set(Calendar.MONTH, Integer.parseInt(data.substring(4, 6)) - 1);
		gc.set(Calendar.DAY_OF_MONTH, Integer.parseInt(data.substring(6, 8)));
		gc.set(Calendar.HOUR_OF_DAY, 0);
		gc.set(Calendar.MINUTE, 0);
		gc.set(Calendar.SECOND, 0);
		gc.set(Calendar.MILLISECOND, 0);
		return gc.getTime();
	}

}
