/**
 * 
 */
package br.jus.cnj.intercomunicacao;

 import static org.junit.Assert.*;

import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;

import org.junit.Test;

import br.jus.cnj.intercomunicacao.servico.ManifestacaoProcessual;
import br.jus.cnj.intercomunicacao.util.ConversorData;

/**
 * @author cristof
 *
 */
public class TestaEntidadesInteroperabilidade {
	
	@Test
	public void testaDataFormatada(){
		GregorianCalendar gc = new GregorianCalendar(2011, 2, 22, 15, 20, 15);
		assertEquals("20110322", ConversorData.converteParaDataInteroperabilidade(gc.getTime()));
		assertEquals("20110322152015", ConversorData.converteParaDataHoraInteroperabilidade(gc.getTime()));
		gc.set(Calendar.YEAR, 2011);
		gc.set(Calendar.MONTH, 2);
		gc.set(Calendar.DAY_OF_MONTH, 22);
		gc.set(Calendar.HOUR_OF_DAY, 0);
		gc.set(Calendar.MINUTE, 0);
		gc.set(Calendar.SECOND, 0);
		GregorianCalendar gc2 = new GregorianCalendar();
		gc2.setTime(ConversorData.converteDeDataInteroperabilidade("20110322"));
		assertTrue(gc.compareTo(gc2) == 0);
		gc.set(Calendar.YEAR, 2011);
		gc.set(Calendar.MONTH, 2);
		gc.set(Calendar.DAY_OF_MONTH, 22);
		gc.set(Calendar.HOUR_OF_DAY, 1);
		gc.set(Calendar.MINUTE, 2);
		gc.set(Calendar.SECOND, 3);
		gc2.setTime(ConversorData.converteDeDataHoraInteroperabilidade("20110322010203"));
		assertTrue(gc.compareTo(gc2) == 0);
	}
	
	@Test
	public void testaPessoa(){
		Pessoa pessoa = Pessoa.Factory.newInstance();
		pessoa.setNome("Paulo Cristovão Filho");
		pessoa.setDataNascimento("19770718");
		pessoa.setEstadoNatural("PB");
		pessoa.setCidadeNatural("João Pessoa");
		DocumentoIdentificacao documentoCPF = pessoa.addNewDocumento();
		documentoCPF.setCodigoDocumento("02184786403");
		documentoCPF.setTipoDocumento(ModalidadeDocumentoIdentificador.CMF);
		documentoCPF.setEmissorDocumento("SRFB");
		Endereco endereco = pessoa.addNewEndereco();
		endereco.setCep("70363110");
		endereco.setComplemento("ap. 503");
		System.out.println("Pessoa: " + pessoa.toString());
		assertTrue(pessoa.getEnderecoList().size() > 0);
	}
	
	@Test
	public void testaEntregaManifestacaoSimples(){
		ManifestacaoProcessual manifestacao = ManifestacaoProcessual.Factory.newInstance();
		
		manifestacao.setIdManifestante("02184786403");
		manifestacao.setSenhaManifestante("senha");
		manifestacao.setNumeroProcesso("00012476020112000000");
		manifestacao.setDataEnvio(ConversorData.converteParaDataHoraInteroperabilidade(new Date()));
		DocumentoProcessual doc = manifestacao.addNewDocumento();
		doc.setConteudo("Meu texto aqui.".getBytes());
		doc.addAssinatura("assinatura".getBytes());
		doc.setDataHora(ConversorData.converteParaDataHoraInteroperabilidade(new Date()));
		doc.setMimetype("text/plain");
		doc.setNivelSigilo(0);
		doc.setTipoDocumento("petição");
		System.out.println("Manifestação: \n----------------" + manifestacao.toString() + "-----------------------");
		assertTrue(manifestacao.toString().length() > 0);
	}
	
	@Test
	public void testaEntregaManifestacaoInicial(){
		ManifestacaoProcessual m = ManifestacaoProcessual.Factory.newInstance();
		
		m.setIdManifestante("02184786403");
		m.setSenhaManifestante("senha");
		
		CabecalhoProcessual c = m.addNewDadosBasicos();
		PoloProcessual pAtivo = c.addNewPolo();
		pAtivo.setPolo(ModalidadePoloProcessual.A);
		Parte parte0 = pAtivo.addNewParte();
		Pessoa p0 = parte0.addNewPessoa();
		Endereco ep0 = p0.addNewEndereco();
		ep0.setCep("50363110");

		PoloProcessual pPassivo = c.addNewPolo();
		pPassivo.setPolo(ModalidadePoloProcessual.P);
		System.out.println("Manifestacao: [" + m.toString() + "]");
		assertTrue(true);
		
	}
	
}
